@@ -1,11 +1,13 @@
 from dynabuffers.api.ISerializable import ISerializable, ByteBuffer
 from dynabuffers.ast.ClassType import ClassType
+from dynabuffers.ast.structural.UnionOptions import UnionOptions
 
 
 class UnionTypeOptions():
-    def __init__(self, name: str, values: [str]):
+    def __init__(self, name: str, values: [str], options: UnionOptions):
         self.name = name
         self.values = values
+        self.options = options
 
 
 class UnionType(ISerializable):
@@ -40,6 +42,9 @@ class UnionType(ISerializable):
 
             if ":type" in value and value[":type"] == classes.index(clazz):
                 return clazz
+            if ":type" in value and value[":type"] in self.options.values \
+                    and self.options.values.index(value[":type"]) == classes.index(clazz):
+                return clazz
             if fields1 == fields2:
                 return clazz
 
